skill

# XMLRésuméLibrary: User Guide

score | Element Reference | skillarea

## Name

skill — A name and/or description of a skill

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
level | CDATA | None
targets | CDATA | None

## Description

The `skill` element describes something that a person is skilled at.

### Parents

`skill` may be contained in these elements: `skills`, `skillset`

### Attributes

`level`

  The `level` attribute indicates a person's level of proficiency at a skill. “Level of proficiency” may be expressed in any manner, such as “3 years” (three years of experience with a particular skill), “expert”, or “7/10”. The `skills.level.display` parameter determines whether or not skill levels are displayed in formatted output.

## See Also

`achievement`, `skills.format`, `skills.level.display`.

## Examples

    <skill>Singing</skill>

    <skill level="3 years">Java Programming</skill>

    <skill level="certified glutton">Eating</skill>

    <skill level="beginner">
      Throwing <emphasis>large</emphasis> objects
    </skill>

score | Element Reference | skillarea